@@ -120,6 +120,12 @@ def preprocessing_training_common(df, config, industry_dictionary, state_diction
     cols_to_drop = config['cols_to_drop'][model_type]
     df = utils.drop_columns( df=df, columns=cols_to_drop )
 
+    # Campaign should be the first column after targets and date ( we put it in place 0 now, targets and date will be
+    # placed in 0 too afterwards)
+    status_col = df['idCampaign']
+    df.drop( labels=['idCampaign'], axis=1, inplace=True )
+    df.insert(loc=0, value=status_col, column= 'idCampaign')
+
     return df,imp
 
 
@@ -157,7 +163,6 @@ def preprocessing_training(df, industry_dictionary, state_dictionary,
                                                     model_type=model_type,
                                                     imp=imp )
 
-    df_leads_clean = utils.reduce_mem_usage_category( df=df_leads_clean )
     if(use_one_hot_encoding):
         df_leads_clean = utils.one_hot_encoding( df=df_leads_clean )
 
